==> open-cluster-management-policy-model-6.6.2-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1beta1/AutomationDefFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AutomationDefFluentImpl<A extends AutomationDefFluent<A>> extends BaseFluent<A> implements AutomationDefFluent<A>{
  public AutomationDefFluentImpl() {
  }
  public AutomationDefFluentImpl(AutomationDef instance) {
    this.withExtraVars(instance.getExtraVars()); 
    this.withName(instance.getName()); 
    this.withSecret(instance.getSecret()); 
    this.withType(instance.getType()); 
  }
  private Map<String,Object> extraVars;
  private String name;
  private String secret;
  private String type;
  public A addToExtraVars(String key,Object value) {
    if(this.extraVars == null && key != null && value != null) { this.extraVars = new LinkedHashMap(); }
    if(key != null && value != null) {this.extraVars.put(key, value);} return (A)this;
  }
  public A addToExtraVars(Map<String,Object> map) {
    if(this.extraVars == null && map != null) { this.extraVars = new LinkedHashMap(); }
    if(map != null) { this.extraVars.putAll(map);} return (A)this;
  }
  public A removeFromExtraVars(String key) {
    if(this.extraVars == null) { return (A) this; }
    if(key != null && this.extraVars != null) {this.extraVars.remove(key);} return (A)this;
  }
  public A removeFromExtraVars(Map<String,Object> map) {
    if(this.extraVars == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.extraVars != null){this.extraVars.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getExtraVars() {
    return this.extraVars;
  }
  public <K,V>A withExtraVars(Map<String,Object> extraVars) {
    if (extraVars == null) { this.extraVars =  null;} else {this.extraVars = new LinkedHashMap(extraVars);} return (A) this;
  }
  public Boolean hasExtraVars() {
    return this.extraVars != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getSecret() {
    return this.secret;
  }
  public A withSecret(String secret) {
    this.secret=secret; return (A) this;
  }
  public Boolean hasSecret() {
    return this.secret != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AutomationDefFluentImpl that = (AutomationDefFluentImpl) o;
    if (extraVars != null ? !extraVars.equals(that.extraVars) :that.extraVars != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    if (secret != null ? !secret.equals(that.secret) :that.secret != null) return false;
    if (type != null ? !type.equals(that.type) :that.type != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(extraVars,  name,  secret,  type,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (extraVars != null && !extraVars.isEmpty()) { sb.append("extraVars:"); sb.append(extraVars + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (secret != null) { sb.append("secret:"); sb.append(secret + ","); }
    if (type != null) { sb.append("type:"); sb.append(type); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> open-cluster-management-policy-model-6.7.2-sources.jar: io/fabric8/openclustermanagement/api/model/governancepolicypropagator/policy/v1beta1/AutomationDefFluentImpl.java <==
package io.fabric8.openclustermanagement.api.model.governancepolicypropagator.policy.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AutomationDefFluentImpl<A extends AutomationDefFluent<A>> extends BaseFluent<A> implements AutomationDefFluent<A>{
  public AutomationDefFluentImpl() {
  }
  public AutomationDefFluentImpl(AutomationDef instance) {
    if (instance != null) {
      this.withExtraVars(instance.getExtraVars());
      this.withName(instance.getName());
      this.withSecret(instance.getSecret());
      this.withType(instance.getType());
    }
  }
  private Map<String,Object> extraVars;
  private String name;
  private String secret;
  private String type;
  public A addToExtraVars(String key,Object value) {
    if(this.extraVars == null && key != null && value != null) { this.extraVars = new LinkedHashMap(); }
    if(key != null && value != null) {this.extraVars.put(key, value);} return (A)this;
  }
  public A addToExtraVars(Map<String,Object> map) {
    if(this.extraVars == null && map != null) { this.extraVars = new LinkedHashMap(); }
    if(map != null) { this.extraVars.putAll(map);} return (A)this;
  }
  public A removeFromExtraVars(String key) {
    if(this.extraVars == null) { return (A) this; }
    if(key != null && this.extraVars != null) {this.extraVars.remove(key);} return (A)this;
  }
  public A removeFromExtraVars(Map<String,Object> map) {
    if(this.extraVars == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.extraVars != null){this.extraVars.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getExtraVars() {
    return this.extraVars;
  }
  public <K,V>A withExtraVars(Map<String,Object> extraVars) {
    if (extraVars == null) { this.extraVars =  null;} else {this.extraVars = new LinkedHashMap(extraVars);} return (A) this;
  }
  public Boolean hasExtraVars() {
    return this.extraVars != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public String getSecret() {
    return this.secret;
  }
  public A withSecret(String secret) {
    this.secret=secret; return (A) this;
  }
  public Boolean hasSecret() {
    return this.secret != null;
  }
  public String getType() {
    return this.type;
  }
  public A withType(String type) {
    this.type=type; return (A) this;
  }
  public Boolean hasType() {
    return this.type != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AutomationDefFluentImpl that = (AutomationDefFluentImpl) o;
    if (!java.util.Objects.equals(extraVars, that.extraVars)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    if (!java.util.Objects.equals(secret, that.secret)) return false;

    if (!java.util.Objects.equals(type, that.type)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(extraVars,  name,  secret,  type,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (extraVars != null && !extraVars.isEmpty()) { sb.append("extraVars:"); sb.append(extraVars + ","); }
    if (name != null) { sb.append("name:"); sb.append(name + ","); }
    if (secret != null) { sb.append("secret:"); sb.append(secret + ","); }
    if (type != null) { sb.append("type:"); sb.append(type); }
    sb.append("}");
    return sb.toString();
  }
  
}
